# Cloudflare Worker 部署说明

本文档提供关于如何部署 Cloudflare Worker 代码的说明，该代码用于处理和代理 LobeChat 插件的请求到 Cloudflare AI API。

## 前提条件

1. 一个 Cloudflare 账户
2. 已启用 Cloudflare Workers 服务
3. 安装并配置了 [Wrangler CLI](https://developers.cloudflare.com/workers/cli-wrangler/install-update)（Cloudflare 的 Worker CLI 工具）

## 部署步骤

### 1. 准备工作

首先，确保你已经获取了以下信息：

- 你的 Cloudflare 账户 ID（可在 Cloudflare 控制台中找到）
- 一个有权限访问 Cloudflare Workers 和 AI API 的 API Token

### 2. 创建 Worker 项目

使用 Wrangler 创建一个新的 Worker 项目：

```bash
# 创建新项目
wrangler init ai-image-proxy-worker
cd ai-image-proxy-worker
```

### 3. 配置 Worker

将本仓库中的 `src/worker.ts` 文件内容复制到你的 Worker 项目的主文件中（通常是 `src/index.ts`）。

然后，创建或修改 `wrangler.toml` 文件如下：

```toml
name = "ai-image-proxy-worker"
compatibility_date = "2023-10-30"

[vars]
# 这里不要填写敏感信息，这些只是占位符
# 实际密钥应使用 Secrets 设置

# 可选：如果你需要绑定自定义域名
# [routes]
# pattern = "your-domain.com/*"
# zone_id = "your-zone-id"
```

### 4. 设置环境变量（Secrets）

使用 Wrangler 设置必要的 Secrets：

```bash
# 设置客户端 API 密钥（你自己定义的值，用于客户端访问你的 Worker）
wrangler secret put WORKER_API_KEY

# 设置 Cloudflare API Token（从 Cloudflare 控制台获取）
wrangler secret put CLOUDFLARE_API_TOKEN

# 设置 Cloudflare 账户 ID
wrangler secret put CLOUDFLARE_ACCOUNT_ID
```

每条命令运行后，将提示你输入相应的值。

### 5. 部署 Worker

完成配置后，部署 Worker：

```bash
wrangler deploy
```

成功部署后，Wrangler 将显示你的 Worker 的 URL，例如：`https://ai-image-proxy-worker.yourusername.workers.dev`。

### 6. 配置 LobeChat 插件

按照 README 中的说明配置 LobeChat 插件，将 `WORKER_API_KEY` 设置为你在步骤 4 中配置的客户端 API 密钥。

## 故障排除

如果遇到问题，请检查：

1. Cloudflare 控制台中的 Worker 日志
2. 确保所有环境变量（Secrets）都已正确设置
3. 验证你的 API Token 是否有足够的权限
4. 检查你的账户是否启用了 Workers AI 服务

## 安全注意事项

- 定期轮换你的 API 密钥和令牌
- 为 Worker API 密钥使用强密码，因为这是客户端用来访问你的 Worker 的凭证
- 考虑添加速率限制或其他安全措施来防止滥用

## 资源链接

- [Cloudflare Workers 文档](https://developers.cloudflare.com/workers/)
- [Workers AI 文档](https://developers.cloudflare.com/workers-ai/) 